package com.zd.laboratory.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zd.laboratory.mapper.LabPintsScoreSiteMapper;
import com.zd.laboratory.domain.LabPintsScoreSite;
import com.zd.laboratory.service.ILabPintsScoreSiteService;

/**
 * ��值条件设置Service业务层处理
 * 
 * @author zd
 * @date 2021-12-13
 */
@Service
public class LabPintsScoreSiteServiceImpl implements ILabPintsScoreSiteService 
{
    @Autowired
    private LabPintsScoreSiteMapper labPintsScoreSiteMapper;

    /**
     * 查询��值条件设置
     * 
     * @param id ��值条件设置主键
     * @return ��值条件设置
     */
    @Override
    public LabPintsScoreSite selectLabPintsScoreSiteById(Long id)
    {
        return labPintsScoreSiteMapper.selectLabPintsScoreSiteById(id);
    }

    /**
     * 查询��值条件设置列表
     * 
     * @param labPintsScoreSite ��值条件设置
     * @return ��值条件设置
     */
    @Override
    public List<LabPintsScoreSite> selectLabPintsScoreSiteList(LabPintsScoreSite labPintsScoreSite)
    {
        return labPintsScoreSiteMapper.selectLabPintsScoreSiteList(labPintsScoreSite);
    }

    /**
     * 新增��值条件设置
     * 
     * @param labPintsScoreSite ��值条件设置
     * @return 结果
     */
    @Override
    public int insertLabPintsScoreSite(LabPintsScoreSite labPintsScoreSite)
    {
        return labPintsScoreSiteMapper.insertLabPintsScoreSite(labPintsScoreSite);
    }

    /**
     * 修改��值条件设置
     * 
     * @param labPintsScoreSite ��值条件设置
     * @return 结果
     */
    @Override
    public int updateLabPintsScoreSite(LabPintsScoreSite labPintsScoreSite)
    {
        return labPintsScoreSiteMapper.updateLabPintsScoreSite(labPintsScoreSite);
    }

    /**
     * 批量删除��值条件设置
     * 
     * @param ids 需要删除的��值条件设置主键
     * @return 结果
     */
    @Override
    public int deleteLabPintsScoreSiteByIds(Long[] ids)
    {
        return labPintsScoreSiteMapper.deleteLabPintsScoreSiteByIds(ids);
    }

    /**
     * 删除��值条件设置信息
     * 
     * @param id ��值条件设置主键
     * @return 结果
     */
    @Override
    public int deleteLabPintsScoreSiteById(Long id)
    {
        return labPintsScoreSiteMapper.deleteLabPintsScoreSiteById(id);
    }
}
