package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabPintsScoreSite;
import com.zd.laboratory.service.ILabPintsScoreSiteService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.swagger.config.Knife4jConfiguration;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * ��值条件设置Controller
 *
 * @author zd
 * @date 2021-12-13
 */
@RestController
@Api(tags = "【��值条件设置】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@RequestMapping("/pintsScoreSite")
public class LabPintsScoreSiteController extends BaseController
{
    @Autowired
    private ILabPintsScoreSiteService labPintsScoreSiteService;

    /**
     * 查询��值条件设置列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_PINTSSCORESITE + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询��值条件设置列表")
    public TableDataInfo<LabPintsScoreSite> list(LabPintsScoreSite labPintsScoreSite)
    {
        startPage();
        List<LabPintsScoreSite> list = labPintsScoreSiteService.selectLabPintsScoreSiteList(labPintsScoreSite);
        return getDataTable(list);
    }

    /**
     * 导出��值条件设置列表
     */
    @ApiOperation(value = "导出��值条件设置列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_PINTSSCORESITE + PerFun.EXPORT)
    @Log(title = "��值条件设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabPintsScoreSite labPintsScoreSite) throws IOException
    {
        List<LabPintsScoreSite> list = labPintsScoreSiteService.selectLabPintsScoreSiteList(labPintsScoreSite);
        ExcelUtil<LabPintsScoreSite> util = new ExcelUtil<LabPintsScoreSite>(LabPintsScoreSite.class);
        util.exportExcel(response, list, "��值条件设置数据");
    }

    /**
     * 获取��值条件设置详细信息
     */
    @ApiOperation(value = "获取��值条件设置详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_PINTSSCORESITE + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabPintsScoreSite> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labPintsScoreSiteService.selectLabPintsScoreSiteById(id));
    }

    /**
     * 新增��值条件设置
     */
    @ApiOperation(value = "新增��值条件设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_PINTSSCORESITE + PerFun.ADD)
    @Log(title = "��值条件设置", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabPintsScoreSite labPintsScoreSite)
    {
        return ResultData.result(labPintsScoreSiteService.insertLabPintsScoreSite(labPintsScoreSite));
    }

    /**
     * 修改��值条件设置
     */
    @ApiOperation(value = "修改��值条件设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_PINTSSCORESITE + PerFun.EDIT)
    @Log(title = "��值条件设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabPintsScoreSite labPintsScoreSite)
    {
        return  ResultData.result(labPintsScoreSiteService.updateLabPintsScoreSite(labPintsScoreSite));
    }

    /**
     * 删除��值条件设置
     */
    @ApiOperation(value = "删除��值条件设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_PINTSSCORESITE + PerFun.REMOVE)
    @Log(title = "��值条件设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labPintsScoreSiteService.deleteLabPintsScoreSiteByIds(ids));
    }
}
